"""Log mixin module.

Defines a log mixin class allowing classes to get a logger with the name of the module,
class and method it was called from.

"""
import inspect
import logging
from types import FrameType


class LogMixin(object):
    """Log mixin class.

    Adds a method to classes that returns a logger whose name is
    {module}.{class}.{method}.

    """
    @staticmethod
    def get_logger() -> logging.Logger:
        """Returns a logger whose name is {module}.{class}.{method}."""
        f: FrameType | None = inspect.currentframe().f_back

        if isinstance(f, FrameType):

            a: str = f.f_globals["__name__"]
            try:
                b: str = f.f_locals["self"].__class__.__name__
            except KeyError:
                try:
                    b: str = f.f_locals["cls"].__name__
                except KeyError:
                    b: str = "unknown"
            c: str = f.f_code.co_name
            return logging.getLogger(f"{a}.{b}.{c}")

        else:

            logger: logging.Logger = logging.getLogger(__name__)
            logger.warning("Could not get logger name from frame; using __name__.")
            return logger


def get_logger() -> logging.Logger:
    """Returns a logger with the name of the module and function that created it."""
    fr: FrameType | None = inspect.currentframe().f_back

    mo: str = fr.f_globals["__name__"]
    fu: str = fr.f_code.co_name

    return logging.getLogger(f"{mo}.{fu}")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['logmixin']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'logmixin',
    'version': '0.1.4',
    'description': 'Defines a mixin class that adds a convenient get_logger method.',
    'long_description': '# logmixin\n\n## Description\n\nThis is an extremely small Python package (one module, ~40 lines) to enable quick and easy logging within class methods.\n\n## Usage\n\nIt defines a mixin class that adds a `get_logger` method to your class. This method returns a logger with the name of\nyour module, class, and method that called it. For example, suppose you have a module called `my_module.py` with these\ncontents:\n\n```python\nimport logging\nfrom logmixin import LogMixin\n\n\nclass MyClass(LogMixin):\n    """A class with logging enabled."""\n    def my_method(self):\n        self.get_logger().info("Hello, world!")\n\n\nif __name__ == "__main__":\n    logging.basicConfig(level=logging.INFO)\n    MyClass().my_method()\n```\n\nIf you run this file, you will see the following output:\n\n```\nINFO:my_module.MyClass.my_method:Hello, world!\n```\n\n## Installation\n\nYou can install this package from PyPI:\n\n```bash\npip install logmixin\n```\n\n## License\n\nMIT\n\n\n\n',
    'author': 'Sam Mathias',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/sammosummo/logmixin',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
